@@ -42,6 +42,15 @@ def is_number(data):
         return False
 
 
+def is_finite(data):
+    """
+    Check if the given data is a finite number
+    :param data: Input can be string, number or nan
+    :return: True or False
+    """
+    return is_number(data) and np.isfinite(data)
+
+
 def to_number(data):
     """
     Check and return if the data can be cast to a number, else return None
